import request from '@/utils/request'

// 查询家族成员列表
export function listMember(query) {
  return request({
    url: '/system/member/list',
    method: 'get',
    params: query
  })
}
// 查询家族树 列表
export function listTree(query) {
  return request({
    url: '/system/member/treeList',
    method: 'get',
    params: query
  })
}
// 查询未在家族树的成员 列表
export function listNotTree(query) {
  return request({
    url: '/system/member/notTreeList',
    method: 'get',
    params: query
  })
}

// 查询家族成员详细
export function getMember(id) {
  return request({
    url: '/system/member/get/' + id,
    method: 'get'
  })
}

// 新增家族成员
export function addMember(data) {
  return request({
    url: '/system/member',
    method: 'post',
    data: data
  })
}

// 修改家族成员
export function updateMember(data) {
  return request({
    url: '/system/member',
    method: 'put',
    data: data
  })
}

// 删除家族成员
export function delMember(familyId,id) {
  return request({
    url: '/system/member/'+familyId+'/' + id,
    method: 'delete'
  })
}

// 导出家族成员
export function exportMember(query) {
  return request({
    url: '/system/member/export',
    method: 'get',
    params: query
  })
}

// 添加至家族树
export function saveToTree(data) {
  return request({
    url: '/system/member/saveToTree',
    method: 'post',
    data: data
  })
}
// 移除出家族树
export function delToTree(familyId,id) {
  return request({
    url: '/system/member/delToTree/'+familyId+'/' + id,
    method: 'delete'
  })
}
