<template>
  <div class="app-container">
    <span><i class="el-icon-share"></i> 家族树 - {{ familyName }}</span>
    <el-divider></el-divider>
    <el-form :model="queryParams" ref="queryForm" :inline="true" v-show="showSearch" label-width="68px">
      <el-form-item label="模糊条件" prop="searchValue">
        <el-input
          v-model="queryParams.searchValue"
          placeholder="请输入姓名/手机号"
          clearable
          size="small"
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item>
        <el-button type="cyan" icon="el-icon-search" size="mini" @click="handleQuery">搜索</el-button>
        <el-button icon="el-icon-refresh" size="mini" @click="resetQuery">重置</el-button>
      </el-form-item>
    </el-form>
    
    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button
          type="primary"
          icon="el-icon-plus"
          size="mini"
          :disabled="single"
          @click="handleAdd"
          v-hasPermi="['system:member:add']"
        >添加</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="success"
          icon="el-icon-edit"
          size="mini"
          :disabled="single"
          @click="handleUpdate"
          v-hasPermi="['system:member:edit']"
        >修改</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="danger"
          icon="el-icon-delete"
          size="mini"
          :disabled="multiple"
          @click="handleDelete"
          v-hasPermi="['system:member:remove']"
        >删除</el-button>
      </el-col>
	  <right-toolbar :showSearch.sync="showSearch" @queryTable="getList"></right-toolbar>
    </el-row>
    
    <el-table v-loading="loading" :data="memberList" @selection-change="handleSelectionChange">
      <el-table-column type="selection" width="55" align="center" />
      <el-table-column label="主键ID" align="center" prop="memberId" v-if="false"/>
      <el-table-column label="ID" align="center" prop="qrcode" width="150" />
      <el-table-column label="姓名" align="center" prop="name" width="100" />
      <el-table-column label="性别" align="center" prop="gender" :formatter="genderFormat" width="50" />
      <el-table-column label="父辈" align="center" prop="father" width="100" />
      <el-table-column label="手机号" align="center" prop="mobile" width="200" />
      <el-table-column label="配偶" align="center" prop="spouse" width="100" />
      <el-table-column label="操作" align="center" class-name="small-padding fixed-width">
        <template slot-scope="scope">
          <el-button
            size="mini"
            type="text"
            icon="el-icon-edit"
            @click="handleUpdate(scope.row)"
            v-hasPermi="['system:member:edit']"
          >修改</el-button>
          <el-button
            size="mini"
            type="text"
            icon="el-icon-delete"
            @click="handleDelete(scope.row)"
            v-hasPermi="['system:member:remove']"
          >移除</el-button>
        </template>
      </el-table-column>
    </el-table>
    
    <pagination
      v-show="total>0"
      :total="total"
      :page.sync="queryParams.pageNum"
      :limit.sync="queryParams.pageSize"
      @pagination="getList"
    />

    <!-- 添加或修改家族成员对话框 -->
    <el-dialog :title="title" :visible.sync="open" width="500px" append-to-body :close-on-click-modal=false>
      <el-form ref="form" :model="form" :rules="rules" label-width="80px">

        <el-form-item label="父辈" prop="father">
          <el-input v-model="form.father" placeholder="" :readonly="readonly"/>
        </el-form-item>

        <el-form-item label="姓名" prop="memberId">
          <el-select v-model="form.memberId" placeholder="请选择">
            <el-option v-for="member in memberOptions" :key="member.memberId" :label="member.name" :value="member.memberId"></el-option>
          </el-select>
        </el-form-item>

        <el-form-item label="备注" prop="remark">
          <el-input v-model="form.remark" type="textarea" placeholder="请输入内容" />
        </el-form-item>
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitForm">确 定</el-button>
        <el-button @click="cancel">取 消</el-button>
      </div>
    </el-dialog>
  </div>
</template>

<script>
import { getFamily } from "@/api/system/family";
import { listTree,listNotTree,getMember, delMember, addMember, updateMember,saveToTree,delToTree } from "@/api/system/member";

export default {
  name: "Tree",
  data() {
    return {
      familyName: null,
      // 遮罩层
      loading: true,
      loadings: false,
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 家族成员表格数据
      memberList: [],
      // 弹出层标题
      title: "",
      // 是否显示弹出层
      open: false,
      readonly: false,
      // 成员
      memberOptions:[],
      genderOptions:[],
      parentId: null,
      father: null,
      // 查询参数
      memberParams: {
        enable: 0,
        familyId: null,
        searchValue: null,
      },
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 10,
        familyId: null,
        name: null,
        gender: null,
      },
      // 表单参数
      form: {},
      // 表单校验
      rules: {}
    }
  },
  activated() {
    const fid = this.$route.query.fid;
    this.queryParams.familyId = fid;
    this.getFamily(fid);
    this.getList();
    this.getDicts("sys_user_sex").then((response) => {
      this.genderOptions = response.data;
    });
    this.getDicts("app_member_state").then((response) => {
      this.stateOptions = response.data;
    });
  },
  methods: {
    getFamily(id){
      getFamily(id).then(response => {
        this.familyName = response.data.fullName;
      });
    },
    getNotTree() {
      this.memberParams.familyId = this.queryParams.familyId;
      listNotTree(this.memberParams).then(response => {
        this.memberOptions = response.data;
        console.log(this.memberOptions)
      });
    },
    /** 查询家族成员列表 */
    getList() {
      this.loading = true;
      listTree(this.queryParams).then(response => {
        this.memberList = response.rows;
        this.total = response.total;
        this.loading = false;
      });
    },
    // 性别 字典翻译
    genderFormat(row, column) {
      return this.selectDictLabel(this.genderOptions, row.gender);
    },
    // 状态 字典翻译
    stateFormat(row, column) {
      return this.selectDictLabel(this.stateOptions, row.state);
    },
    // 取消按钮
    cancel() {
      this.open = false;
      this.reset();
    },
    // 表单重置
    reset() {
      this.form = {
        parentId: null,
        father: null,
        memberId: null,
        userId: null,
        spouseUserId: null,
        name: null,
        birthday: null,
        gender: null,
        education: null,
        state: null,
        createBy: null,
        createTime: null,
        updateBy: null,
        updateTime: null,
        remark: null
      };
      this.resetForm("form");
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1;
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm("queryForm");
      this.handleQuery();
    },
    // 多选框选中数据
    handleSelectionChange(selection) {
      this.ids = selection.map(item => item.memberId)
      this.single = selection.length!==1
      this.multiple = !selection.length

      if(selection.length===1){
        this.parentId = selection.map(item => item.memberId)[0]
        this.father = selection.map(item => item.name)[0]
      }
    },
    /** 新增按钮操作 */
    handleAdd(row) {
      this.reset();
      this.form.parentId = this.parentId;
      this.form.father = this.father;
      this.open = true;
      this.title = "添加成员至家族树";
      this.getNotTree();
    },
    /** 修改按钮操作 */
    handleUpdate(row) {
      this.reset();
      const id = row.memberId || this.ids
      getMember(id).then(response => {
        this.form = response.data;
        this.form.familyId = this.queryParams.familyId;
        this.open = true;
        this.title = "修改家族树成员";
        this.getNotTree();
      });
    },
    addForm(){
      this.$refs["form"].validate(valid => {
        if (valid) {
          this.form.familyId = this.queryParams.familyId;
            saveToTree(this.form).then(response => {
              if (response.code === 200) {
                this.msgSuccess("新增成功");
                this.open = false;
                this.getList();
              }
            });
        }
      });
    },
    updateForm(){
      this.$refs["form"].validate(valid => {
        if (valid) {
          this.form.familyId = this.queryParams.familyId;
          updateMember(this.form).then(response => {
              if (response.code === 200) {
                this.msgSuccess("修改成功");
                this.open = false;
                this.getList();
              }
            });
        }
      });
    },
    /** 提交按钮 */
    submitForm() {
      this.$refs["form"].validate(valid => {
        if (valid) {
          this.form.familyId = this.queryParams.familyId;
            saveToTree(this.form).then(response => {
              if (response.code === 200) {
                this.msgSuccess("保存成功");
                this.open = false;
                this.getList();
              }
            });
        }
      });
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      const ids = row.memberId || this.ids;
      var familyId = this.queryParams.familyId;
      this.$confirm('是否确认移除?', "警告", {
          confirmButtonText: "确定",
          cancelButtonText: "取消",
          type: "warning"
        }).then(function() {
          return delToTree(familyId,ids);
        }).then(() => {
          this.getList();
          this.msgSuccess("移除成功");
        }).catch(function() {});
    },
  }    
}
</script>